@@ -1,12 +1,13 @@
-from typing import Optional
+from typing import Optional, Union
 
 import urwid
+from deltachat import const
 
 from ..event import ChatListMonitor
 
 
 class ListItem(urwid.Button):
-    def __init__(self, caption: tuple, callback, arg=None) -> None:
+    def __init__(self, caption: Union[tuple, str], callback, arg=None) -> None:
         super().__init__("")
         urwid.connect_signal(self, "click", callback, arg)
         self._w = urwid.AttrMap(
@@ -47,8 +48,11 @@ class ChatListWidget(urwid.ListBox, ChatListMonitor):
 
         # build the chat list
         for i, chat in enumerate(chats):
+            if chat.id < 10:
+                continue
             pos += 1
-            label = "➜ " + chat.get_name()
+            chat_type = "@" if chat.get_type() == const.DC_CHAT_TYPE_SINGLE else "#"
+            label = f"{chat_type} {chat.get_name()}"
             new_messages = chat.count_fresh_messages()
             if new_messages > 0:
                 label += f" ({new_messages})"
@@ -59,7 +63,7 @@ class ChatListWidget(urwid.ListBox, ChatListMonitor):
                 self.focus_position = pos
             else:
                 if new_messages > 0:
-                    label = ("unread_chat", label)
+                    label = ("unread_chat", label)  # type: ignore
                 button = ListItem(label, self.chat_change, i)
                 self.chat_list.insert(pos, button)
 
